<?php

namespace EventPortal\Domain\Address\Models;

use EventPortal\Domain\Model;
use EventPortal\Domain\Table\Concerns\HasTable;
use EventPortal\Domain\Venue\Models\Venue;
use Illuminate\Database\Eloquent\Relations\MorphTo;
use Illuminate\Database\Eloquent\Relations\MorphToMany;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class Address extends Model implements AuditableInterface
{
    use HasTable, Auditable;

    public const KEY = 'address';

    protected $fillable = [
        'line_1',
        'line_2',
        'line_3',
        'city',
        'area',
        'area_code',
        'country',
    ];

    protected $appends = [
        'formatted',
        'short_formatted',
    ];

    public function addressable(): MorphTo
    {
        return $this->morphTo();
    }

    public function venues(): MorphToMany
    {
        return $this->morphedByMany(Venue::class, 'addressable');
    }

    public function getFormattedAttribute(): string
    {
        return collect($this->attributes)
            ->only($this->fillable)
            ->filter()
            ->implode(', ');
    }

    public function getShortFormattedAttribute(): string
    {
        return "{$this->line_1}, {$this->city}";
    }
}
