<?php

namespace EventPortal\Domain\Email\Models;

use EventPortal\Contracts\Event;
use EventPortal\Domain\Model;
use EventPortal\Domain\Table\Concerns\HasTable;
use EventPortal\Enums\EmailType;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Support\Str;
use Spatie\Enum\Laravel\HasEnums;

class EventEmail extends Model
{
    use HasEnums, HasTable;

    public const KEY = 'email';

    protected $table = 'event_emails';

    /** @var array<string> */
    protected $fillable = [
        'event_id',
        'type',
        'subject',
        'sender_address',
        'reply_to_address',
    ];

    /** @var array<string> */
    protected $with = [
        'event',
    ];

    /** @var array<string,mixed> */
    protected $enums = [
        'type' => EmailType::class,
    ];

    /** @var array<string> */
    protected $casts = [
        'type' => 'integer',
    ];

    public function event(): BelongsTo
    {
        return $this->belongsTo(resolve(Event::class));
    }

    public function scopeForEvent(Builder $query, Event $event): Builder
    {
        return $query->where('event_id', $event->id);
    }

    /**
     * Build the notification key for the current email via its
     * type e.g. "Save the date" -> "event.save-the-date"
     *
     * @see notifications/event.php
     */
    public function getNotificationKey(): string
    {
        $emailType = Str::slug($this->type->getValue());

        return "event.{$emailType}";
    }
}
