<?php

namespace EventPortal\Http\Controllers\Delegate\Event\Form;

use EventPortal\Domain\Delegate\DelegateForm;
use EventPortal\Domain\Event\Form\Models\Form as FormModel;
use EventPortal\Domain\Event\Form\Models\FormStep;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\ValueObjects\EventDetails;
use EventPortal\Domain\Event\ValueObjects\PageHeader;
use EventPortal\Domain\Util\DelegateRender;
use Illuminate\Http\Request;
use Inertia\Response;

class ViewFormController
{
    public function __invoke(Request $request, Event $event, FormModel $form): Response
    {
        $delegateForm = DelegateForm::make()
            ->forDelegate($request->user()->delegate)
            ->forForm($form)
            ->forEvent($event);

        if ($delegateForm->allStepsCompleted()) {
            return DelegateRender::component('Delegate/Form/Show')
                ->withPageHeader(
                    PageHeader::make()
                        ->title($form->name)
                        ->description('View your details.')
                )
                ->withData($delegateForm->forDisplaying())
                ->get();
        }

        $requestedStep = FormStep::forForm($form)->find($request->step);

        return DelegateRender::component('Delegate/Form/Index')
            ->key('delegate.form.index')
            ->withForm($delegateForm->forEditing($requestedStep))
            ->withEventDetails(EventDetails::make($event))
            ->get();
    }
}
